@@ -12,8 +12,8 @@ ADDR_ECONET: Final = 86
 ATTR_NAME: Final = "name"
 ATTR_VALUE: Final = "value"
 ATTR_EXTRA: Final = "extra"
-ATTR_BOILER_SENSORS: Final = "sensors"
-ATTR_BOILER_PARAMETERS: Final = "parameters"
+ATTR_ECOMAX_SENSORS: Final = "sensors"
+ATTR_ECOMAX_PARAMETERS: Final = "parameters"
 ATTR_PENDING_ALERTS: Final = "pending_alerts"
 ATTR_ALERTS: Final = "alerts"
 ATTR_FAN_POWER: Final = "fan_power"
